@@ -1,5 +1,4 @@
 import logging
-import multiprocessing.pool
 import os
 import sys
 import uuid
@@ -34,7 +33,8 @@ class LocalClient(AbstractClient):
         super().__init__(*args, **kwargs)
 
         # Will create a pool with os.cpu_count() processes
-        self._pool = multiprocessing.pool.Pool()
+        from concurrent.futures import ProcessPoolExecutor
+        self._executor = ProcessPoolExecutor()
 
     def start_job(self, katscript):
         job_identifier = str(uuid.uuid4())
@@ -45,13 +45,12 @@ class LocalClient(AbstractClient):
         logging.info(katscript)
         logging.info(job_identifier)
 
-        self._pool.apply_async(
-            _start_wrapper, (
-                self._exec_path,
-                job_identifier,
-                self._session_klass,
-                katscript
-            )
+        self._executor.submit(
+            _start_wrapper,
+            self._exec_path,
+            job_identifier,
+            self._session_klass,
+            katscript
         )
 
         return job_identifier
@@ -66,6 +65,9 @@ class LocalClient(AbstractClient):
     def get_job_status(self, job_identifier):
         status = self.db.get_job_status(job_identifier)
 
+        if type(status) is tuple:
+            return status
+
         # If the job status is less than or equal to RUNNING, then we need to derive the current job status and update
         # the job status accordingly.
         new_status = status
