@@ -12,15 +12,16 @@ import paramiko
 from finorch.config.config import api_config_manager
 from finorch.transport.abstract_transport import AbstractTransport
 from finorch.transport.exceptions import TransportConnectionException, TransportTerminateException, \
-    TransportGetJobFileException, TransportGetJobFileListException, TransportGetJobStatusException, \
-    TransportGetJobsException
+    TransportGetJobFileException, TransportGetJobFileListException, TransportGetJobStatusException
 
 
 class SshTransport(AbstractTransport):
     def __init__(self, session, exec_path, *args, **kwargs):
         super().__init__(session, exec_path, *args, **kwargs)
 
-        self._ssh_client = None
+        # exec path must exist for ssh session
+        assert exec_path
+
         self._ssh_transport = None
         self._ssh_session = None
 
@@ -35,13 +36,16 @@ class SshTransport(AbstractTransport):
 
         self._remote_port = None
 
-    def connect(self, *args, **kwargs):
-        self._remote_port = kwargs['remote_port']
-        self._remote_port = int(self._remote_port) if self._remote_port else None
+        from finorch.sessions import SshSession
+        self._is_generic = isinstance(self._session, SshSession)
 
         self._ssh_client = paramiko.SSHClient()
         self._ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
 
+    def connect(self, *args, **kwargs):
+        self._remote_port = kwargs['remote_port']
+        self._remote_port = int(self._remote_port) if self._remote_port else None
+
         # If no ssh password is provided, then try to use the key from the api settings
         if not self._ssh_password:
             # Get the configuration for the specified session
@@ -50,7 +54,7 @@ class SshTransport(AbstractTransport):
                 raise TransportConnectionException("No password provided, and no key set")
 
             # Check if it has a key or not
-            key = section.get('key', None)
+            key = section.get('key' if not self._is_generic else self._host, None)
             if not key:
                 raise TransportConnectionException("No password provided, and no key set")
 
@@ -115,22 +119,22 @@ class SshTransport(AbstractTransport):
         session.exec_command(command)
 
         # Wait for the connection to close
-        stdout, stderr = b'', b''
+        stdout, stderr = '', ''
         while True:  # monitoring process
             # Reading from output streams
             while session.recv_ready():
-                stdout += session.recv(1000)
+                stdout += session.recv(1000).decode('utf-8')
             while session.recv_stderr_ready():
-                stderr += session.recv_stderr(1000)
+                stderr += session.recv_stderr(1000).decode('utf-8')
             if session.exit_status_ready():  # If completed
                 break
             sleep(0.1)
 
-        stdout = stdout.decode('utf-8')
-        stderr = stderr.decode('utf-8')
+            if stdout.splitlines() and stdout.splitlines()[-1] == "=EOF=":
+                break
 
         # Check that the command finished successfully
-        if session.exit_status:
+        if session.exit_status_ready() and session.exit_status:
             raise TransportConnectionException(
                 f"Unable to start remote server.\nstdout:\n{stdout}\n\nstderr:\n{stderr}\n"
             )
@@ -170,7 +174,11 @@ class SshTransport(AbstractTransport):
         return self._remote_port
 
     def disconnect(self):
-        raise NotImplementedError()
+        super().disconnect()
+
+        self._connection.shutdown()
+        self._ssh_client.close()
+        self._connected = False
 
     def get_job_file(self, job_identifier, file_path):
         status = self._client_rpc.get_job_file(job_identifier, file_path)
@@ -181,7 +189,7 @@ class SshTransport(AbstractTransport):
 
     def get_job_file_list(self, job_identifier):
         status = self._client_rpc.get_job_file_list(job_identifier)
-        if type(status) is list:
+        if type(status) is list and status[0] is not None:
             return status
         else:
             raise TransportGetJobFileListException(status[1])
@@ -194,11 +202,7 @@ class SshTransport(AbstractTransport):
             raise TransportGetJobStatusException(status[1])
 
     def get_jobs(self):
-        status = self._client_rpc.get_jobs()
-        if type(status) is list:
-            return status
-        else:
-            raise TransportGetJobsException(status[1])
+        return self._client_rpc.get_jobs()
 
     def start_job(self, katscript):
         return self._client_rpc.start_job(katscript)
@@ -207,7 +211,6 @@ class SshTransport(AbstractTransport):
         return self._client_rpc.stop_job(job_identifier)
 
     def terminate(self):
-        print(self._connected)
         if not self._connected:
             raise TransportTerminateException("Client is not connected")
 
