@@ -41,4 +41,4 @@ def run():
 
 
 if __name__ == '__main__':
-    run()
+    run()   # pragma: no cover
